pub fn dst_transitions_for_year(
std_offset: i32,
dst_offset: i32,
start: DstRule,
end: DstRule,
year: i64,
) -> [ZoneTransition; 2]Expand description
The two UTC transitions for year of a zone with a regular DST schedule: spring-forward
(std_offset → dst_offset) at start, fall-back (dst_offset → std_offset) at end. Each
rule’s time_seconds is wall-clock local in the offset in effect just before the transition.